@@ -42,6 +42,8 @@ class Initialization(Utils):
     def __init__(self, check):
         self.check = check
         self.meta = _meta_
+        self.arch = _meta_.arch
+        self.slack_ver = slack_ver()
         self.def_repos_dict = Repo().default_repository()
         self.conf_path = self.meta.conf_path
         self.log_path = self.meta.log_path
@@ -56,22 +58,32 @@ class Initialization(Utils):
     def constructing(self):
         """Creating the all necessary directories
         """
-        if not os.path.exists(self.conf_path):
-            os.mkdir(self.conf_path)
-        if not os.path.exists(self.log_path):
-            os.mkdir(self.log_path)
-        if not os.path.exists(self.lib_path):
-            os.mkdir(self.lib_path)
-        if not os.path.exists(self.tmp_path):
-            os.mkdir(self.tmp_path)
-        if not os.path.exists(self.build_path):
-            os.makedirs(self.build_path)
-        if not os.path.exists(self._SOURCES):
-            os.makedirs(self._SOURCES)
-        if not os.path.exists(self.slpkg_tmp_packages):
-            os.makedirs(self.slpkg_tmp_packages)
-        if not os.path.exists(self.slpkg_tmp_patches):
-            os.makedirs(self.slpkg_tmp_patches)
+        paths_basic = [
+            self.conf_path,
+            self.log_path,
+            self.lib_path,
+            self.tmp_path
+        ]
+
+        paths_extra = [
+            self.build_path,
+            self._SOURCES,
+            self.slpkg_tmp_packages,
+            self.slpkg_tmp_patches
+        ]
+
+        self.make_dir(paths_basic)
+        self.make_dirs(paths_extra)
+
+    def make_dir(self, path: list):
+        for p in path:
+            if not os.path.exists(p):
+                os.mkdir(p)
+
+    def make_dirs(self, path: list):
+        for p in path:
+            if not os.path.exists(p):
+                os.makedirs(p)
 
     def custom(self, name):
         """Creating user select repository local library
@@ -84,10 +96,7 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
+        self.make_dir([log, lib])
         PACKAGES_TXT = f"{repo}/{lib_file}"
         FILELIST_TXT = ""
         CHECKSUMS_MD5 = f"{repo}{md5_file}"
@@ -110,14 +119,11 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
         dirs = ["core/", "extra/", "patches/"]
-        for d in dirs:
-            if not os.path.exists(lib + d):
-                os.mkdir(lib + d)
+        self.make_dir([log, lib])
+        self.make_dir([f"{lib}{dirs[0]}",
+                       f"{lib}{dirs[1]}",
+                       f"{lib}{dirs[2]}"])
         PACKAGES_TXT = mirrors(lib_file, "")
         FILELIST_TXT = ""
         CHECKSUMS_MD5 = mirrors(md5_file, "")
@@ -155,14 +161,11 @@ class Initialization(Utils):
         # lst_file = ""
         # md5_file = ""
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        SLACKBUILDS_TXT = f"{repo}{slack_ver()}/{lib_file}"
+        self.make_dir([log, lib])
+        SLACKBUILDS_TXT = f"{repo}{self.slack_ver}/{lib_file}"
         FILELIST_TXT = ""
         CHECKSUMS_MD5 = ""
-        ChangeLog_txt = f"{repo}{slack_ver()}/{log_file}"
+        ChangeLog_txt = f"{repo}{self.slack_ver}/{log_file}"
         if self.check:
             return self.checks_logs(log, ChangeLog_txt)
         self.down(lib, SLACKBUILDS_TXT, repo_name)
@@ -181,14 +184,11 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        PACKAGES_TXT = f"{repo}{slack_ver()}/{lib_file}"
+        self.make_dir([log, lib])
+        PACKAGES_TXT = f"{repo}{self.slack_ver}/{lib_file}"
         FILELIST_TXT = ""
-        CHECKSUMS_MD5 = f"{repo}{slack_ver()}/{md5_file}"
-        ChangeLog_txt = f"{repo}{slack_ver()}/{log_file}"
+        CHECKSUMS_MD5 = f"{repo}{self.slack_ver}/{md5_file}"
+        ChangeLog_txt = f"{repo}{self.slack_ver}/{log_file}"
         if self.check:
             return self.checks_logs(log, ChangeLog_txt)
         self.down(lib, PACKAGES_TXT, repo_name)
@@ -201,8 +201,7 @@ class Initialization(Utils):
         """Creating alien local library
         """
         ar = "x86"
-        ver = slack_ver()
-        arch = self.meta.arch
+        ver = self.slack_ver
         repo = self.def_repos_dict["alien"]
         log = self.log_path + "alien/"
         lib = self.lib_path + "alien_repo/"
@@ -211,12 +210,9 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
-            ar = arch
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
+            ar = self.arch
         if self.meta.slack_rel == "current":
             ver = self.meta.slack_rel
         PACKAGES_TXT = f"{repo}/{ver}/{ar}/{lib_file}"
@@ -235,7 +231,6 @@ class Initialization(Utils):
         """Creating slacky.eu local library
         """
         ar = ""
-        arch = self.meta.arch
         repo = self.def_repos_dict["slacky"]
         log = self.log_path + "slacky/"
         lib = self.lib_path + "slacky_repo/"
@@ -244,17 +239,14 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "64"
-        PACKAGES_TXT = f"{repo}slackware{ar}-{slack_ver()}/{lib_file}"
+        PACKAGES_TXT = f"{repo}slackware{ar}-{self.slack_ver}/{lib_file}"
         FILELIST_TXT = ""
-        CHECKSUMS_MD5 = f"{repo}slackware{ar}-{slack_ver()}/{md5_file}"
+        CHECKSUMS_MD5 = f"{repo}slackware{ar}-{self.slack_ver}/{md5_file}"
 
-        ChangeLog_txt = f"{repo}slackware{ar}-{slack_ver()}/{log_file}"
+        ChangeLog_txt = f"{repo}slackware{ar}-{self.slack_ver}/{log_file}"
         if self.check:
             return self.checks_logs(log, ChangeLog_txt)
         self.down(lib, PACKAGES_TXT, repo_name)
@@ -274,10 +266,7 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
+        self.make_dir([log, lib])
         PACKAGES_TXT = f"{repo}{lib_file}"
         FILELIST_TXT = ""
         CHECKSUMS_MD5 = f"{repo}{md5_file}"
@@ -293,9 +282,7 @@ class Initialization(Utils):
     def slonly(self):
         """Creating slackers local library
         """
-        ver = slack_ver()
-        ar = f"{ver}-x86"
-        arch = self.meta.arch
+        ar = f"{self.slack_ver}-x86"
         repo = self.def_repos_dict["slonly"]
         log = self.log_path + "slonly/"
         lib = self.lib_path + "slonly_repo/"
@@ -304,15 +291,12 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
-            ar = f"{ver}-x86_64"
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
+            ar = f"{self.slack_ver}-x86_64"
         if self.meta.slack_rel == "current":
             ar = f"{self.meta.slack_rel}-x86"
-        if self.meta.slack_rel == "current" and arch == "x86_64":
+        if self.meta.slack_rel == "current" and self.arch == "x86_64":
             ar = f"{self.meta.slack_rel}-x86_64"
         PACKAGES_TXT = f"{repo}{ar}/{lib_file}"
         FILELIST_TXT = ""
@@ -337,10 +321,7 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
+        self.make_dir([log, lib])
         PACKAGES_TXT = f"{repo}{lib_file}"
         FILELIST_TXT = ""
         CHECKSUMS_MD5 = f"{repo}{md5_file}"
@@ -356,7 +337,7 @@ class Initialization(Utils):
     def multi(self):
         """Creating alien multilib local library
         """
-        ver = slack_ver()
+        ver = self.slack_ver
         repo = self.def_repos_dict["multi"]
         log = self.log_path + "multi/"
         lib = self.lib_path + "multi_repo/"
@@ -365,10 +346,7 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
+        self.make_dir([log, lib])
         if self.meta.slack_rel == "current":
             ver = self.meta.slack_rel
         PACKAGES_TXT = f"{repo}{ver}/{lib_file}"
@@ -387,7 +365,6 @@ class Initialization(Utils):
         """Creating Slacke local library
         """
         ar = ""
-        arch = self.meta.arch
         repo = self.def_repos_dict["slacke"]
         log = self.log_path + "slacke/"
         lib = self.lib_path + "slacke_repo/"
@@ -396,17 +373,17 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "64"
         version = self.meta.slacke_sub_repo[1:-1]
-        PACKAGES_TXT = f"{repo}slacke{version}/slackware{ar}-{slack_ver()}/{lib_file}"
+        PACKAGES_TXT = (f"{repo}slacke{version}/slackware{ar}-"
+                        f"{self.slack_ver}/{lib_file}")
         FILELIST_TXT = ""
-        CHECKSUMS_MD5 = f"{repo}slacke{version}/slackware{ar}-{slack_ver()}/{md5_file}"
-        ChangeLog_txt = f"{repo}slacke{version}/slackware{ar}-{slack_ver()}/{log_file}"
+        CHECKSUMS_MD5 = (f"{repo}slacke{version}/slackware{ar}-"
+                         f"{self.slack_ver}/{md5_file}")
+        ChangeLog_txt = (f"{repo}slacke{version}/slackware{ar}-"
+                         f"{self.slack_ver}/{log_file}")
         if self.check:
             return self.checks_logs(log, ChangeLog_txt)
         self.down(lib, PACKAGES_TXT, repo_name)
@@ -419,7 +396,6 @@ class Initialization(Utils):
         """Creating SalixOS local library
         """
         ar = "i486"
-        arch = self.meta.arch
         repo = self.def_repos_dict["salix"]
         log = self.log_path + "salix/"
         lib = self.lib_path + "salix_repo/"
@@ -428,16 +404,13 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "x86_64"
-        PACKAGES_TXT = f"{repo}{ar}/{slack_ver()}/{lib_file}"
+        PACKAGES_TXT = f"{repo}{ar}/{self.slack_ver}/{lib_file}"
         FILELIST_TXT = ""
-        CHECKSUMS_MD5 = f"{repo}{ar}/{slack_ver()}/{md5_file}"
-        ChangeLog_txt = f"{repo}{ar}/{slack_ver()}/{log_file}"
+        CHECKSUMS_MD5 = f"{repo}{ar}/{self.slack_ver}/{md5_file}"
+        ChangeLog_txt = f"{repo}{ar}/{self.slack_ver}/{log_file}"
         if self.check:
             return self.checks_logs(log, ChangeLog_txt)
         self.down(lib, PACKAGES_TXT, repo_name)
@@ -450,7 +423,6 @@ class Initialization(Utils):
         """Creating slackel.gr local library
         """
         ar = "i486"
-        arch = self.meta.arch
         repo = self.def_repos_dict["slackl"]
         log = self.log_path + "slackl/"
         lib = self.lib_path + "slackl_repo/"
@@ -459,11 +431,8 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "x86_64"
         PACKAGES_TXT = f"{repo}{ar}/current/{lib_file}"
         FILELIST_TXT = ""
@@ -488,10 +457,7 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
+        self.make_dir([log, lib])
         PACKAGES_TXT = f"{repo}{lib_file}"
         FILELIST_TXT = ""
         CHECKSUMS_MD5 = f"{repo}{md5_file}"
@@ -508,8 +474,7 @@ class Initialization(Utils):
         """Creating MATE local library
         """
         ar = "x86"
-        ver_slack = slack_ver()
-        arch = self.meta.arch
+        ver_slack = self.slack_ver
         repo = self.def_repos_dict["msb"]
         log = self.log_path + "msb/"
         lib = self.lib_path + "msb_repo/"
@@ -518,11 +483,8 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "x86_64"
         version = self.meta.msb_sub_repo[1:-1]
         if self.meta.slack_rel == "current":
@@ -543,8 +505,7 @@ class Initialization(Utils):
         """Creating Cinnamon local library
         """
         ar = "x86"
-        ver_slack = slack_ver()
-        arch = self.meta.arch
+        ver_slack = self.slack_ver
         repo = self.def_repos_dict["csb"]
         log = self.log_path + "csb/"
         lib = self.lib_path + "csb_repo/"
@@ -553,11 +514,8 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "x86_64"
         if self.meta.slack_rel == "current":
             ver_slack = self.meta.slack_rel
@@ -578,7 +536,6 @@ class Initialization(Utils):
         """
         nickname = "slack-n-free"
         ar = ""
-        arch = self.meta.arch
         repo = self.def_repos_dict["connos"]
         log = self.log_path + "connos/"
         lib = self.lib_path + "connos_repo/"
@@ -587,16 +544,13 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "64"
-        PACKAGES_TXT = f"{repo}{nickname}{ar}-{slack_ver()}/{lib_file}"
+        PACKAGES_TXT = f"{repo}{nickname}{ar}-{self.slack_ver}/{lib_file}"
         FILELIST_TXT = ""
-        CHECKSUMS_MD5 = f"{repo}{nickname}{ar}-{slack_ver()}/{md5_file}"
-        ChangeLog_txt = f"{repo}{nickname}{ar}-{slack_ver()}/{log_file}"
+        CHECKSUMS_MD5 = f"{repo}{nickname}{ar}-{self.slack_ver}/{md5_file}"
+        ChangeLog_txt = f"{repo}{nickname}{ar}-{self.slack_ver}/{log_file}"
         if self.check:
             return self.checks_logs(log, ChangeLog_txt)
         self.down(lib, PACKAGES_TXT, repo_name)
@@ -609,7 +563,6 @@ class Initialization(Utils):
         """Creating Microlinux local library
         """
         ar = "32"
-        arch = self.meta.arch
         repo = self.def_repos_dict["mles"]
         log = self.log_path + "mles/"
         lib = self.lib_path + "mles_repo/"
@@ -618,17 +571,14 @@ class Initialization(Utils):
         # lst_file = ""
         md5_file = "CHECKSUMS.md5"
         log_file = "ChangeLog.txt"
-        if not os.path.exists(log):
-            os.mkdir(log)
-        if not os.path.exists(lib):
-            os.mkdir(lib)
-        if arch == "x86_64":
+        self.make_dir([log, lib])
+        if self.arch == "x86_64":
             ar = "64"
         version = self.meta.mles_sub_repo[1:-1]
-        PACKAGES_TXT = f"{repo}{version}-{slack_ver()}-{ar}bit/{lib_file}"
+        PACKAGES_TXT = f"{repo}{version}-{self.slack_ver}-{ar}bit/{lib_file}"
         FILELIST_TXT = ""
-        CHECKSUMS_MD5 = f"{repo}{version}-{slack_ver()}-{ar}bit/{md5_file}"
-        ChangeLog_txt = f"{repo}{version}-{slack_ver()}-{ar}bit/{log_file}"
+        CHECKSUMS_MD5 = f"{repo}{version}-{self.slack_ver}-{ar}bit/{md5_file}"
+        ChangeLog_txt = f"{repo}{version}-{self.slack_ver}-{ar}bit/{log_file}"
         if self.check:
             return self.checks_logs(log, ChangeLog_txt)
         self.down(lib, PACKAGES_TXT, repo_name)
@@ -746,10 +696,11 @@ class Update:
     def __init__(self):
         self.meta = _meta_
         self.grey = _meta_.color["GREY"]
+        self.green = _meta_.color["GREEN"]
         self.red = _meta_.color["RED"]
         self.cyan = _meta_.color["CYAN"]
         self.endc = _meta_.color["ENDC"]
-        self.done = f"{self.grey}Done{self.endc}\n"
+        self.done = f"{self.green}Done{self.endc}\n"
         self.error = f"{self.red}Error{self.endc}\n"
 
     def run(self, repos):
@@ -758,6 +709,7 @@ class Update:
         print("\nCheck and update repositories:\n")
         default = self.meta.default_repositories
         enabled = self.meta.repositories
+        custom = Repo().custom_repository()
 
         # Replace the enabled repositories from user defined
         if repos:
@@ -766,11 +718,11 @@ class Update:
         for repo in enabled:
             if check_for_local_repos(repo) is True:
                 continue
-            print(f"{self.grey}Check repository [{self.cyan}{repo}{self.grey}] ... {self.endc}", end="", flush=True)
+            self.done_msg(repo)
             if repo in default:
                 getattr(Initialization(False), repo)()
                 print(self.done, end="")
-            elif repo in enabled:
+            elif repo in custom:
                 Initialization(False).custom(repo)
                 print(self.done, end="")
             else:
@@ -778,6 +730,11 @@ class Update:
         print()   # new line at end
         raise SystemExit()
 
+    def done_msg(self, repo):
+        print(f"{self.grey}Check repository "
+              f"[{self.cyan}{repo}{self.grey}] ... "
+              f"{self.endc}", end="", flush=True)
+
 
 def check_exists_repositories(repo):
     """Checking if repositories exists by PACKAGES.TXT file
@@ -785,12 +742,10 @@ def check_exists_repositories(repo):
     pkg_list = "PACKAGES.TXT"
     if repo == "sbo":
         pkg_list = "SLACKBUILDS.TXT"
-    if check_for_local_repos(repo) is True:
+    elif check_for_local_repos(repo) is True:
         pkg_list = "PACKAGES.TXT"
-        return ""
     if not os.path.isfile(f"{_meta_.lib_path}{repo}_repo/{pkg_list}"):
-        return repo
-    return ""
+        return False
 
 
 def check_for_local_repos(repo):
