@@ -88,11 +88,7 @@ class ArgParse(BlackList):
             "clean"
         ]
 
-        # checking if repositories exists
-        enabled_repos = _meta_.repositories
-        if len(self.args) > 1:
-            repo = check_exists_repositories(args[1])
-        if len(self.args) > 1 and self.args[0] in [
+        options = [
             "-c", "--check",
             "-l", "--list",
             "-c", "--check",
@@ -101,11 +97,19 @@ class ArgParse(BlackList):
             "-p", "--desc",
             "-F", "--FIND",
             "-f", "--find"
-        ] and self.args[1] == repo and repo in enabled_repos:
+        ]
+
+        # checking if repositories exists
+        enabled_repos = _meta_.repositories
+        if len(self.args) > 1:
+            repo = self.args[1]
+            check = check_exists_repositories(repo)
+        if (len(self.args) > 1 and self.args[0] in options
+                and check is False and repo in enabled_repos):
             print("\n  Please update the packages lists. Run 'slpkg update'.\n"
                   "  This command should be used to synchronize the packages\n"
                   "  lists from the repositories that are enabled.\n")
-            raise SystemExit()
+            raise SystemExit(1)
 
     def help_version(self):
         """Help and version info
@@ -117,7 +121,7 @@ class ArgParse(BlackList):
                 self.args[1:] == []):
             prog_version()
         else:
-            usage("")
+            usage("", 1)
 
     def command_update(self):
         """Update package lists repositories
@@ -126,14 +130,14 @@ class ArgParse(BlackList):
         if len(self.args) == 1 and self.args[0] == "update":
             update.run(repos="")
         elif (len(self.args) == 2 and self.args[0] == "update" and
-                self.args[1].startswith("--repositories=")):
+                self.args[1].startswith("--repos=")):
             repos = self.args[1].split("=")[-1].split(",")
             for rp in repos:
                 if rp not in self.meta.repositories:
-                    repos.remove(rp)
+                    usage(rp, 1)
             update.run(repos)
         else:
-            usage("")
+            usage("", 1)
 
     def command_upgrade(self):
         """Recreate repositories package lists
@@ -142,14 +146,14 @@ class ArgParse(BlackList):
         if len(self.args) == 1 and self.args[0] == "upgrade":
             upgrade.run(repos="")
         elif (len(self.args) == 2 and self.args[0] == "upgrade" and
-                self.args[1].startswith("--repositories=")):
+                self.args[1].startswith("--repos=")):
             repos = self.args[1].split("=")[-1].split(",")
             for rp in repos:
                 if rp not in self.meta.repositories:
-                    repos.remove(rp)
+                    usage(rp, 1)
             upgrade.run(repos)
         else:
-            usage("")
+            usage("", 1)
 
     def command_update_slpkg(self):
         """Slpkg it self update
@@ -157,7 +161,7 @@ class ArgParse(BlackList):
         if len(self.args) == 2 and self.args[0] == "update-slpkg":
             it_self_update()
         else:
-            usage("")
+            usage("", 1)
 
     def command_repo_enable(self):
         """Repositories enable/disable
@@ -166,7 +170,7 @@ class ArgParse(BlackList):
         if len(self.args) == 1 and self.args[0] == "repo-enable":
             RepoEnable().choose()
         else:
-            usage("")
+            usage("", 1)
 
     def command_repo_list(self):
         """Repositories list
@@ -174,7 +178,7 @@ class ArgParse(BlackList):
         if len(self.args) == 1 and self.args[0] == "repo-list":
             RepoList().repos()
         else:
-            usage("")
+            usage("", 1)
 
     def command_repo_add(self):
         """Add custom repositories
@@ -182,7 +186,7 @@ class ArgParse(BlackList):
         if len(self.args) == 3 and self.args[0] == "repo-add":
             Repo().add(self.args[1], self.args[2])
         else:
-            usage("")
+            usage("", 1)
 
     def command_repo_remove(self):
         """Remove custom repositories
@@ -190,7 +194,7 @@ class ArgParse(BlackList):
         if len(self.args) == 2 and self.args[0] == "repo-remove":
             Repo().remove(self.args[1])
         else:
-            usage("")
+            usage("", 1)
 
     def command_repo_info(self):
         """Repositories informations
@@ -201,9 +205,9 @@ class ArgParse(BlackList):
             RepoInfo().view(self.args[1])
         elif (len(self.args) > 1 and self.args[0] == "repo-info" and
                 self.args[1] not in RepoList().all_repos):
-            usage(self.args[1])
+            usage(self.args[1], 1)
         else:
-            usage("")
+            usage("", 1)
 
     def command_health(self):
         """Check package health
@@ -214,7 +218,7 @@ class ArgParse(BlackList):
                 self.args[1] == "--silent"):
             PackageHealth(mode=self.args[1]).test()
         else:
-            usage("")
+            usage("", 1)
 
     def command_deps_status(self):
         """Print dependencies status
@@ -234,7 +238,7 @@ class ArgParse(BlackList):
                 "--tree" in self.args and image):
             DependenciesStatus(image).tree()
         else:
-            usage("")
+            usage("", 1)
 
     def command_new_config(self):
         """Manage .new configuration files
@@ -242,14 +246,14 @@ class ArgParse(BlackList):
         if len(self.args) == 1 and self.args[0] == "new-config":
             NewConfig().run()
         else:
-            usage("")
+            usage("", 1)
 
     def command_clean_tmp(self):
         """Clean all downloaded packages and sources"""
         if len(self.args) == 1 and self.args[0] == "clean-tmp":
             clean_tmp()
         else:
-            usage("")
+            usage("", 1)
 
     def auto_build(self):
         """Auto built tool
@@ -261,7 +265,7 @@ class ArgParse(BlackList):
         if len(self.args) >= 3 and self.args[0] in options:
             AutoBuild(self.args[1], self.args[2:], self.meta.path).run()
         else:
-            usage("")
+            usage("", 1)
 
     def pkg_list(self):
         """List of packages by repository
@@ -280,8 +284,7 @@ class ArgParse(BlackList):
             if flag[2] == arg:
                 name = True
             if arg not in flag:
-                usage("")
-                raise SystemExit()
+                usage("", 1)
         if (len(self.args) > 1 and len(self.args) <= 5 and
                 self.args[0] in options):
             if self.args[1] in self.meta.repositories:
@@ -290,9 +293,9 @@ class ArgParse(BlackList):
                                                          INDEX,
                                                          installed)
             else:
-                usage(self.args[1])
+                usage(self.args[1], 1)
         else:
-            usage("")
+            usage("", 1)
 
     def pkg_upgrade(self):
         """Check and upgrade packages by repository
@@ -327,16 +330,16 @@ class ArgParse(BlackList):
                 SBoInstall(sbo_upgrade(skip, flag), flag).start(
                     is_upgrade=True)
             else:
-                usage(self.args[1])
+                usage(self.args[1], 1)
         elif len(self.args) == 1 and self.args[0] in options:
             Updates(repo="").ALL()
         elif len(self.args) == 2 and self.args[0] in options:
             Updates(self.args[1]).run()
         elif (len(self.args) >= 2 and self.args[0] in options and
               self.args[1] not in self.meta.repositories):
-            usage(self.args[1])
+            usage(self.args[1], 1)
         else:
-            usage("")
+            usage("", 1)
 
     def __pkg_upgrade_flags(self, flags):
         """Manage flags for package upgrade option
@@ -344,8 +347,7 @@ class ArgParse(BlackList):
         # Check for typos or unssuported flags
         for arg in self.args[2:]:
             if arg not in flags:
-                usage("")
-                raise SystemExit()
+                usage("", 1)
 
         flag, skip = [], ""
         if flags[0] in self.args:
@@ -397,9 +399,9 @@ class ArgParse(BlackList):
                     self.args[1] in self.meta.repositories):
                 SBoInstall(self.args[2:], flag).start(is_upgrade=False)
             else:
-                usage(self.args[1])
+                usage(self.args[1], 1)
         else:
-            usage("")
+            usage("", 1)
 
     def pkg_tracking(self):
         """Tracking package dependencies
@@ -428,17 +430,16 @@ class ArgParse(BlackList):
         for arg in self.args:
             if arg.startswith("--"):
                 if arg not in additional_options:
-                    usage("")
-                    raise SystemExit()
+                    usage("", 1)
         if (len(self.args) >= 3 and len(self.args) <= 3 and
                 self.args[0] in options and
                 self.args[1] in self.meta.repositories):
             TrackingDeps(self.args[2], self.args[1], flag).run()
         elif (len(self.args) >= 2 and
                 self.args[1] not in self.meta.repositories):
-            usage(self.args[1])
+            usage(self.args[1], 1)
         else:
-            usage("")
+            usage("", 1)
 
     def sbo_network(self):
         """View slackbuilds packages
@@ -466,7 +467,7 @@ class ArgParse(BlackList):
                 additional_options[0] in flag):
             SBoNetwork("", flag).view()
         else:
-            usage("sbo")
+            usage("sbo", 1)
 
     def pkg_blacklist(self):
         """Manage blacklist packages
@@ -496,7 +497,7 @@ class ArgParse(BlackList):
             self.args.remove(flag[1])
             self.black_remove(self.args[1:])
         else:
-            usage("")
+            usage("", 1)
 
     def pkg_queue(self):
         """Manage packages in queue
@@ -542,7 +543,7 @@ class ArgParse(BlackList):
             queue.build()
             queue.install()
         else:
-            usage("")
+            usage("", 1)
 
     def bin_install(self):
         """Install Slackware binary packages
@@ -570,7 +571,7 @@ class ArgParse(BlackList):
                 packages = self.args[2:]
             PackageManager(packages).install(flag)
         else:
-            usage("")
+            usage("", 1)
 
     def bin_upgrade(self):
         """Install-upgrade Slackware binary packages
@@ -593,7 +594,7 @@ class ArgParse(BlackList):
                 packages = self.args[2:]
             PackageManager(packages).upgrade(flag)
         else:
-            usage("")
+            usage("", 1)
 
     def bin_remove(self):
         """Remove Slackware packages
@@ -637,7 +638,7 @@ class ArgParse(BlackList):
                 packages = [""]
             PackageManager(packages).remove(flag, extra)
         else:
-            usage("")
+            usage("", 1)
 
     def bin_find(self):
         """Find installed packages
@@ -663,7 +664,7 @@ class ArgParse(BlackList):
         elif len(self.args) > 1 and self.args[0] in options:
             PackageManager(packages).find(flag)
         else:
-            usage("")
+            usage("", 1)
 
     def pkg_desc(self):
         """Print slack-desc by repository
@@ -687,8 +688,7 @@ class ArgParse(BlackList):
                 self.args.remove(arg)
                 break
         if tag and tag not in colors:
-            print(f"\nslpkg: Error: Available colors {colors}\n")
-            raise SystemExit()
+            raise SystemExit(f"\nslpkg: Error: Available colors {colors}\n")
         if (len(self.args) == 3 and self.args[0] in options and
                 self.args[1] in self.meta.repositories and tag in colors):
             PkgDesc(self.args[2], self.args[1], tag).view()
@@ -697,9 +697,9 @@ class ArgParse(BlackList):
             PkgDesc(self.args[2], self.args[1], paint="").view()
         elif (len(self.args) > 1 and self.args[0] in options and
                 self.args[1] not in self.meta.repositories):
-            usage(self.args[1])
+            usage(self.args[1], 1)
         else:
-            usage("")
+            usage("", 1)
 
     def pkg_find(self):
         """Find packages from all enabled repositories
@@ -718,7 +718,7 @@ class ArgParse(BlackList):
         if len(self.args) > 1 and self.args[0] in options:
             FindFromRepos().find(packages, flag)
         else:
-            usage("")
+            usage("", 1)
 
     def pkg_contents(self):
         """Print packages contents
@@ -731,7 +731,7 @@ class ArgParse(BlackList):
         if len(self.args) > 1 and self.args[0] in options:
             PackageManager(packages).display()
         else:
-            usage("")
+            usage("", 1)
 
     def congiguration(self):
         """Manage slpkg configuration file
@@ -756,7 +756,7 @@ class ArgParse(BlackList):
                 self.args[1] == (command[2])):
             conf.reset()
         else:
-            usage("")
+            usage("", 1)
 
     def auto_detect(self, args):
         """Check for already Slackware binary packages exist
@@ -781,15 +781,14 @@ class ArgParse(BlackList):
             if not_found:
                 for ntf in not_found:
                     self.msg.pkg_not_found("", ntf, "Not installed", "")
-            raise SystemExit()
+            raise SystemExit(1)
 
     def if_checklist(self):
         try:
             from dialog import Dialog
         except ImportError:
-            print("Require 'pythondialog': Install with 'slpkg -s sbo "
-                  "python3-pythondialog'")
-            raise SystemExit()
+            raise SystemExit("Require 'pythondialog': Install with 'slpkg "
+                             "-s sbo python3-pythondialog'")
 
 
 def main():
@@ -800,8 +799,7 @@ def main():
     argparse = ArgParse(args)
 
     if len(args) == 0:
-        usage("")
-        raise SystemExit()
+        usage("", 1)
 
     argparse.auto_detect(args)
 
@@ -861,7 +859,7 @@ def main():
     try:
         arguments[args[0]]()
     except KeyError:
-        usage("")
+        usage("", 1)
 
 
 if __name__ == "__main__":
