@@ -67,7 +67,7 @@ class PackageManager(Utils):
                 if os.path.isfile(self.meta.pkg_path + check):
                     print("Completed!\n")
                 else:
-                    raise SystemExit()
+                    raise SystemExit(1)
             except subprocess.CalledProcessError:
                 self._not_found("Can't install", self.binary, pkg)
                 raise SystemExit(1)
@@ -82,7 +82,7 @@ class PackageManager(Utils):
                 if os.path.isfile(self.meta.pkg_path + check):
                     print("Completed!\n")
                 else:
-                    raise SystemExit()
+                    raise SystemExit(1)
             except subprocess.CalledProcessError:
                 self._not_found("Can't upgrade", self.binary, pkg)
                 raise SystemExit(1)
@@ -116,8 +116,7 @@ class PackageManager(Utils):
                         "\nAre you sure to remove {0} {1} [y/N]? ".format(
                             str(len(self.removed)), msg))
             except EOFError:
-                print()   # new line at exit
-                raise SystemExit()
+                raise SystemExit(1)
             if remove_pkg in ["y", "Y"]:
                 self._check_if_used(self.binary)
                 for rmv in self.removed:
@@ -153,8 +152,7 @@ class PackageManager(Utils):
                     "other packages) [y/N]? ")
                 print()
             except EOFError:
-                print()  # new line at exit
-                raise SystemExit()
+                raise SystemExit("\n")
         return remove_dep
 
     def _get_removed(self):
@@ -187,8 +185,7 @@ class PackageManager(Utils):
             for pkg in self.binary:
                 name = GetFromInstalled(pkg).name()
                 ver = GetFromInstalled(pkg).version()
-                package = find_package(f"{name}-{ver}{self.meta.sp}",
-                                       self.meta.pkg_path)
+                package = find_package(f"{name}-{ver}-", self.meta.pkg_path)
                 if pkg and name == pkg:
                     removed.append(pkg)
                     packages.append(package[0])
@@ -217,7 +214,8 @@ class PackageManager(Utils):
         else:
             for rmv, pkg in zip(removed, packages):
                 self._sizes(pkg)
-                print(f"[ {self.red}delete{self.endc} ] --> [ {self.file_size} ] - {pkg}")
+                print(f"[ {self.red}delete{self.endc} ] --> "
+                      f"[ {self.file_size} ] - {pkg}")
             self._calc_sizes()
             self._remove_summary()
         if "--third-party" in self.extra:
@@ -278,7 +276,7 @@ class PackageManager(Utils):
                 print(f"| Found dependencies for the package {package}:")
                 self.msg.template(78)
                 for pkg in packages:
-                    find = find_package(pkg + self.meta.sp, self.meta.pkg_path)
+                    find = find_package(f"{pkg}-", self.meta.pkg_path)
                     self._sizes(find[0])
                     print(f"| {self.red}{pkg}{self.endc}")
                 self.msg.template(78)
@@ -296,8 +294,7 @@ class PackageManager(Utils):
             if os.path.isfile(self.dep_path + package):
                 os.remove(self.dep_path + package)  # remove log
         except subprocess.CalledProcessError as er:
-            print(er)
-            raise SystemExit()
+            raise SystemExit(er)
 
     def _rmv_deps(self, dependencies, package):
         """Remove dependencies
@@ -332,8 +329,7 @@ class PackageManager(Utils):
             try:
                 self.skip = input(" > ").split()
             except EOFError:
-                print()
-                raise SystemExit()
+                raise SystemExit("\n")
         for s in self.skip:
             if s in self.removed:
                 self.removed.remove(s)
@@ -347,7 +343,8 @@ class PackageManager(Utils):
                 deps = self.read_file(self.dep_path + pkg)
                 for rmv in removes:
                     if GetFromInstalled(rmv).name() and rmv in deps.split():
-                        pkg_dep.append(f"{rmv} is dependency of the package --> {pkg}")
+                        pkg_dep.append(f"{rmv} is dependency of the "
+                                       f"package --> {pkg}")
                         package.append(pkg)
                         dependency.append(rmv)
             if package:
@@ -366,8 +363,8 @@ class PackageManager(Utils):
                         self.red, " " * 30 + "!!! WARNING !!!", self.endc))
                     self.msg.template(78)
                     for p, d in zip(package, dependency):
-                        print(f"| {self.yellow}{d}{self.endc} is dependency of the package --> "
-                              f"{self.green}{p}{self.endc}")
+                        print(f"| {self.yellow}{d}{self.endc} is dependency "
+                              f"of the package --> {self.green}{p}{self.endc}")
                     self.msg.template(78)
                     self._skip_remove()
 
@@ -419,7 +416,8 @@ class PackageManager(Utils):
         for pkgs in packages:
             matching += 1
             self._sizes(pkgs)
-            print(f"[ {self.green}installed{self.endc} ] [ {self.file_size} ] - {pkgs}")
+            print(f"[ {self.green}installed{self.endc} ] "
+                  f"[ {self.file_size} ] - {pkgs}")
         if matching == 0:
             message = "Can't find"
             self.msg.pkg_not_found("", ", ".join(self.binary), message, "\n")
@@ -454,8 +452,7 @@ class PackageManager(Utils):
         for pkg in self.binary:
             name = GetFromInstalled(pkg).name()
             ver = GetFromInstalled(pkg).version()
-            find = find_package(f"{name}-{ver}{self.meta.sp}",
-                                self.meta.pkg_path)
+            find = find_package(f"{name}-{ver}-", self.meta.pkg_path)
             if find:
                 package = self.read_file(
                     self.meta.pkg_path + "".join(find))
@@ -492,7 +489,8 @@ class PackageManager(Utils):
                     pkg = self.list_color_tag(pkg)
                     print(f"{self.grey}{index}:{self.endc} {pkg}")
                     if index == page:
-                        read = input(f"\nPress {self.cyan}Enter{self.endc} to continue... ")
+                        read = input(f"\nPress {self.cyan}Enter{self.endc} to "
+                                     f"continue... ")
                         if read in ["Q", "q"]:
                             break
                         print()   # new line after page
@@ -501,8 +499,7 @@ class PackageManager(Utils):
                     print(pkg)
             print()   # new line at end
         except (EOFError, KeyboardInterrupt, BrokenPipeError, IOError):
-            print()   # new line at exit
-            raise SystemExit()
+            raise SystemExit(1)
 
     def _splitting_packages(self, pkg, repo, name):
         """Return package name from repositories
@@ -551,7 +548,7 @@ class PackageManager(Utils):
         """Tag with color installed packages
         """
         name = GetFromInstalled(pkg).name()
-        find = name + self.meta.sp
+        find = f"{name}-"
         if pkg.endswith(".txz") or pkg.endswith(".tgz"):
             find = pkg[:-4]
         if find_package(find, self.meta.pkg_path):
