@@ -30,13 +30,12 @@ def s_user():
     """Check for root user
     """
     if getpass.getuser() != "root":
-        print("\nslpkg: Error: Must have root privileges\n")
-        raise SystemExit(1)
+        raise SystemExit("\nslpkg: Error: Must have root privileges\n")
 
 
 def virtual_env():
     """Check if a virtual enviroment exists
     """
     if "VIRTUAL_ENV" in os.environ.keys():
-        print("\nslpkg: Error: Please exit from virtual environment first\n")
-        raise SystemExit(1)
+        raise SystemExit("\nslpkg: Error: Please exit from virtual "
+                         "environment first\n")
